==> piwigo-2.1.5.zip: piwigo/plugins/LocalFilesEditor/language/vi_VN/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Cấu hình cục bộ';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_onglet_lang'] = 'Ngôn ngữ';
$lang['locfiledit_onglet_plug'] = 'Plugin cá nhân';
$lang['locfiledit_cant_save'] = 'Tệp tin hiện tại không được phép ghi. Kiểm tra nếu thư mục "include/" có thể ghi được (chmod).';
$lang['locfiledit_newfile'] = 'Tệp tin không tồn tại và sẽ được tạo ra bởi LocalFiles Editor';
$lang['locfiledit_save_config'] = 'Tệp tin đã được ghi thành công.';
$lang['locfiledit_show_default'] = 'Hiển thị tệp tin tham khảo: ';
$lang['locfiledit_save_bak'] = 'Bản sao backup sẽ được tạo ra để dự phòng.';
$lang['locfiledit_saved_bak'] = 'Tệp tin backup file được tạo ra (%s)';
$lang['locfiledit_save_file'] = 'Lưu tệp tin';
$lang['locfiledit_choose_file'] = 'Chọn tệp tin để hiệu chỉnh';
$lang['locfiledit_edit'] = 'Hiệu chỉnh';
$lang['locfiledit_restore'] = 'Phục hồi tệp tin backup';
$lang['locfiledit_restore_confirm'] = 'Vui lòng xác nhận? Việc phục hồi sẽ không có hiệu lực cho đến lần dự phòng tiếp theo.';
$lang['locfiledit_bak_loaded1'] = 'Tệp tin backup đã được nạp.';
$lang['locfiledit_bak_loaded2'] = 'Bạn phải lưu lại tệp tin để phục hồi nó.';
$lang['locfiledit_syntax_error'] = 'Lỗi cú pháp! Tệp tin không thể được lưu.';
$lang['locfiledit_enable_editarea'] = 'Kích hoạt vùng nhập dữ liệu';
$lang['locfiledit_disable_editarea'] = 'Tắt vùng nhập dữ liệu';
$lang['locfiledit_new_tpl'] = 'Tạo tệp tin mới';
$lang['locfiledit_new_filename'] = 'Tên tệp tin';
$lang['locfiledit_model'] = 'Mô hình';
$lang['locfiledit_empty_page'] = 'Trang trống';
$lang['locfiledit_parent_directory'] = 'Thư mục gốc';
$lang['locfiledit_filename_error'] = 'Ký tự bị cấm trong tên tệp tin.';
$lang['locfiledit_file_already_exists'] = 'Tệp tin đã có.';
$lang['locfiledit_model_error'] = 'Bạn phải chọn một mô hình.';
$lang['locfiledit_empty_filename'] = 'Bạn phải điền đủ tên tệp tin.';
$lang['locfiledit_webmaster_only'] = 'Chỉ có webmasters mới có thể tạo hoặc biên tập tệp tin trên máy.';

?>

==> piwigo-2.1.6.zip: piwigo/plugins/LocalFilesEditor/language/vi_VN/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Cấu hình cục bộ';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_onglet_lang'] = 'Ngôn ngữ';
$lang['locfiledit_onglet_plug'] = 'Plugin cá nhân';
$lang['locfiledit_cant_save'] = 'Tệp tin hiện tại không được phép ghi. Kiểm tra nếu thư mục "local/" có thể ghi được (chmod).';
$lang['locfiledit_newfile'] = 'Tệp tin không tồn tại và sẽ được tạo ra bởi LocalFiles Editor';
$lang['locfiledit_save_config'] = 'Tệp tin đã được ghi thành công.';
$lang['locfiledit_show_default'] = 'Hiển thị tệp tin tham khảo: ';
$lang['locfiledit_save_bak'] = 'Bản sao backup sẽ được tạo ra để dự phòng.';
$lang['locfiledit_saved_bak'] = 'Tệp tin backup file được tạo ra (%s)';
$lang['locfiledit_save_file'] = 'Lưu tệp tin';
$lang['locfiledit_choose_file'] = 'Chọn tệp tin để hiệu chỉnh';
$lang['locfiledit_edit'] = 'Hiệu chỉnh';
$lang['locfiledit_restore'] = 'Phục hồi tệp tin backup';
$lang['locfiledit_restore_confirm'] = 'Vui lòng xác nhận? Việc phục hồi sẽ không có hiệu lực cho đến lần dự phòng tiếp theo.';
$lang['locfiledit_bak_loaded1'] = 'Tệp tin backup đã được nạp.';
$lang['locfiledit_bak_loaded2'] = 'Bạn phải lưu lại tệp tin để phục hồi nó.';
$lang['locfiledit_syntax_error'] = 'Lỗi cú pháp! Tệp tin không thể được lưu.';
$lang['locfiledit_enable_editarea'] = 'Kích hoạt vùng nhập dữ liệu';
$lang['locfiledit_disable_editarea'] = 'Tắt vùng nhập dữ liệu';
$lang['locfiledit_new_tpl'] = 'Tạo tệp tin mới';
$lang['locfiledit_new_filename'] = 'Tên tệp tin';
$lang['locfiledit_model'] = 'Mô hình';
$lang['locfiledit_empty_page'] = 'Trang trống';
$lang['locfiledit_parent_directory'] = 'Thư mục gốc';
$lang['locfiledit_filename_error'] = 'Ký tự bị cấm trong tên tệp tin.';
$lang['locfiledit_file_already_exists'] = 'Tệp tin đã có.';
$lang['locfiledit_model_error'] = 'Bạn phải chọn một mô hình.';
$lang['locfiledit_empty_filename'] = 'Bạn phải điền đủ tên tệp tin.';
$lang['locfiledit_webmaster_only'] = 'Chỉ có webmasters mới có thể tạo hoặc biên tập tệp tin trên máy.';

?>
